"use client";
import React, { useState, useEffect, useMemo } from 'react';
import { useRouter } from 'next/navigation';
import { FaMapMarkerAlt, FaBuilding, FaRuler, FaChevronLeft, FaChevronRight } from 'react-icons/fa';

const LandownerPostPage = ({ landownerPostDatas }) => {
  const router = useRouter();
  const [currentImageIndexes, setCurrentImageIndexes] = useState({});
  const BACKEND_URL = 'http://localhost:8000';
  const IMAGE_PATH = '/user-img/user-post-main-img/';
  const PROFILE_IMAGE_PATH = '/user-img/user-images/';

  // Sort the posts by creation date
  const sortedPosts = useMemo(() => {
    if (!landownerPostDatas) return [];

    return landownerPostDatas.map(user => {
      // Sort post_details array by created_at date in descending order
      const sortedPostDetails = [...user.post_details].sort((a, b) => 
        new Date(b.created_at) - new Date(a.created_at)
      );
      
      return {
        ...user,
        post_details: sortedPostDetails,
        mostRecentPost: sortedPostDetails[0]?.created_at || user.created_at
      };
    }).sort((a, b) => new Date(b.mostRecentPost) - new Date(a.mostRecentPost));
  }, [landownerPostDatas]);

  useEffect(() => {
    const initialIndexes = {};
    sortedPosts?.forEach(user => {
      user.post_details.forEach((_, index) => {
        initialIndexes[`${user.id}-${index}`] = 0;
      });
    });
    setCurrentImageIndexes(initialIndexes);
  }, [sortedPosts]);

  const getImageUrl = (imageName) => {
    if (!imageName) return "/buyland.png";
    const cleanImageName = imageName.replace(/^\/+/, '');
    return `${BACKEND_URL}${IMAGE_PATH}${cleanImageName}`;
  };

  const getProfileImageUrl = (imageName) => {
    if (!imageName) return "/profile.png";
    const cleanImageName = imageName.replace(/^\/+/, '');
    return `${BACKEND_URL}${PROFILE_IMAGE_PATH}${cleanImageName}`;
  };

  const handleNextImage = (postKey, currentPhotos) => {
    setCurrentImageIndexes(prev => ({
      ...prev,
      [postKey]: (prev[postKey] + 1) % currentPhotos.length
    }));
  };

  const handlePrevImage = (postKey, currentPhotos) => {
    setCurrentImageIndexes(prev => ({
      ...prev,
      [postKey]: (prev[postKey] - 1 + currentPhotos.length) % currentPhotos.length
    }));
  };

  const renderPropertyDetails = (post) => {
    const postDetails = post.post_details[0];
    const landDistance = postDetails.land_distance;
    const landPrice = postDetails.land_price;
    
    const formatPrice = (price) => {
      return `₹ ${parseFloat(price).toLocaleString('en-IN')} ${landPrice[0].per_unit === 'per-sq-ft' ? 'Per Sq.Ft' : 'Total'}`;
    };

    const handleKnowMore = () => {
      router.push(`/property?postId=${postDetails.id}`);
    };

    const handleContactSeller = () => {
      router.push(`/property?postId=${postDetails.id}`);
    };

    return (
      <div className="flex flex-col gap-2">
        <div className="text-xl font-bold">{formatPrice(landPrice[0].price)}</div>
        <h2 className="text-lg font-semibold">
          {`${postDetails.land_type.charAt(0).toUpperCase() + postDetails.land_type.slice(1)} Land / Plot in ${landDistance[0].locality}`}
        </h2>
        <p className="text-gray-600 text-sm">Posted by {postDetails.user_role}</p>
        
        <div className="bg-gray-100 p-2 rounded-lg grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-2">
          <div className="flex items-center gap-2">
            <FaMapMarkerAlt className="text-gray-600" />
            <div>
              <p className="text-xs">Land Size</p>
              <p className="font-semibold text-sm">{`${postDetails.land_size} ${postDetails.land_size_unit}`}</p>
            </div>
          </div>
          <div className="flex items-center gap-2">
            <FaBuilding className="text-gray-600" />
            <div>
              <p className="text-xs">Land Type</p>
              <p className="font-semibold text-sm">{postDetails.land_type.charAt(0).toUpperCase() + postDetails.land_type.slice(1)}</p>
            </div>
          </div>
          <div className="flex items-center gap-2">
            <FaRuler className="text-gray-600" />
            <div>
              <p className="text-xs">Dimension (L*B)</p>
              <p className="font-semibold text-sm">{postDetails.dimension}</p>
            </div>
          </div>
        </div>

        <div className="flex flex-col sm:flex-row gap-2 text-xs">
          <p className="font-semibold text-blue-600 underline">
            {`${landDistance[0].address}, ${landDistance[0].locality}, ${landDistance[0].city}`}
          </p>
          <div className="flex items-center gap-1 text-red-500 cursor-pointer hover:underline">
            <FaMapMarkerAlt />
            <span>View Map</span>
          </div>
        </div>

        <div className="flex flex-col sm:flex-row items-center justify-between">
          <div className="flex items-center gap-2 mb-2 sm:mb-0">
            <img 
              src={post.profile_photo ? getProfileImageUrl(post.profile_photo) : "/profile.png"} 
              alt="Landowner" 
              className="w-8 h-8 rounded-full object-cover"
            />
            <span className="font-semibold">{post.name}</span>
          </div>
          <div className="flex gap-2">
            <button 
              onClick={handleKnowMore}
              className="bg-white text-purple-600 border border-purple-600 px-4 py-2 rounded-lg text-sm hover:bg-purple-100 transition-colors duration-300"
            >
              Know More  
            </button>
            <button 
              onClick={handleContactSeller}
              className="bg-purple-600 text-white px-4 py-2 rounded-lg text-sm hover:bg-purple-700 transition-colors duration-300"
            >
              Contact Seller
            </button>
          </div>
        </div>
      </div>
    );
  };

  const EmptyState = () => (
    <div className="w-full min-h-[200px] flex flex-col items-center justify-center bg-white rounded-lg shadow-lg p-8">
      <div className="text-gray-400 mb-4">
        <svg className="w-16 h-16" fill="none" stroke="currentColor" viewBox="0 0 24 24">
          <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M19 21V5a2 2 0 00-2-2H7a2 2 0 00-2 2v16m14 0h2m-2 0h-5m-9 0H3m2 0h5M9 7h1m-1 4h1m4-4h1m-1 4h1m-5 10v-5a1 1 0 011-1h2a1 1 0 011 1v5m-4 0h4" />
        </svg>
      </div>
      <h3 className="text-lg font-semibold text-gray-900 mb-2">No Landowner Posts Available</h3>
      <p className="text-gray-600 text-center text-sm">There are currently no property listings from landowners.</p>
    </div>
  );

  const renderImageCarousel = (user, postIndex) => {
    const postKey = `${user.id}-${postIndex}`;
    const photos = user.post_details[postIndex]?.land_photos || [];
    const currentIndex = currentImageIndexes[postKey] || 0;

    return (
      <div className="relative w-full h-48 lg:h-64">
        <img
          src={photos[currentIndex]?.main_img ? getImageUrl(photos[currentIndex].main_img) : "/buyland.png"}
          alt={`Property ${currentIndex + 1}`}
          className="w-full h-full object-cover"
        />
        {photos.length > 1 && (
          <>
            <button
              onClick={(e) => {
                e.preventDefault();
                handlePrevImage(postKey, photos);
              }}
              className="absolute left-2 top-1/2 transform -translate-y-1/2 bg-black bg-opacity-50 text-white p-2 rounded-full hover:bg-opacity-75 transition-opacity"
            >
              <FaChevronLeft className="w-4 h-4" />
            </button>
            <button
              onClick={(e) => {
                e.preventDefault();
                handleNextImage(postKey, photos);
              }}
              className="absolute right-2 top-1/2 transform -translate-y-1/2 bg-black bg-opacity-50 text-white p-2 rounded-full hover:bg-opacity-75 transition-opacity"
            >
              <FaChevronRight className="w-4 h-4" />
            </button>
            <div className="absolute bottom-2 left-1/2 transform -translate-x-1/2 flex gap-1">
              {photos.map((_, index) => (
                <div
                  key={index}
                  className={`w-2 h-2 rounded-full ${
                    index === currentIndex ? 'bg-white' : 'bg-white bg-opacity-50'
                  }`}
                />
              ))}
            </div>
          </>
        )}
        <div className="absolute top-2 right-2">
          <span className="bg-purple-600 text-white px-3 py-1 rounded-full text-xs">
            {user.post_details[postIndex]?.post_type || 'For Sale'}
          </span>
        </div>
      </div>
    );
  };

  return (
    <div className="font-sans w-full">
      {(!sortedPosts || sortedPosts.length === 0) ? (
        <EmptyState />
      ) : (
        <div className="grid gap-4">
          {sortedPosts.map(user => 
            user.post_details.map((_, postIndex) => (
              <div key={`${user.id}-${postIndex}`} className="w-full">
                <div className="bg-white rounded-lg shadow-lg overflow-hidden">
                  <div className="flex flex-col lg:flex-row">
                    <div className="w-full lg:w-1/2 relative">
                      {renderImageCarousel(user, postIndex)}
                    </div>
                    <div className="w-full lg:w-1/2 p-4">
                      {renderPropertyDetails({...user, post_details: [user.post_details[postIndex]]})}
                    </div>
                  </div>
                </div>
              </div>
            ))
          )}
        </div>
      )}
    </div>
  );
};

export default LandownerPostPage;